@@ -19,12 +19,12 @@ class LiveStreamer(_Streamer):
     class for read from a live feed
     """
 
-    def __init__(self, source: str, rate: int, max_errors: int = 3600):
+    def __init__(self, source: str, rate: float, max_errors: int = 3600):
         super().__init__(source, rate)
         self._stream = cv2.VideoCapture(self.source)
         self._fps = self._stream.get(cv2.CAP_PROP_FPS)
-        self._ratio = int(self._fps / rate)
-        self._count = 0
+        self._need_to_wait = - 1. / rate
+        self._last_time = - 1. / rate
         self._error_frames = 0
         self._max_errors = max_errors
 
@@ -51,12 +51,14 @@ class LiveStreamer(_Streamer):
         while self._stream.isOpened():
             ret, frame = self._stream.read()
             if ret:
+                current_time = time.time()
+                need_to_wait = self._last_time + self._need_to_wait - current_time
                 self._error_frames = 0
-                self._count += 1
 
-                if self._count >= self._ratio:
-                    self._count = 0
-                    return frame, time.time()
+                if need_to_wait < 0:
+                    self._last_time = current_time
+                    return frame, current_time
+                time.sleep(need_to_wait * 0.30)
             else:
                 self._error_frames += 1
                 if self._error_frames >= self._max_errors:
