@@ -4,8 +4,10 @@ oss utilities module
 """
 
 from io import BytesIO
+from pathlib import Path
 from typing import List
 
+from lockfile import LockFile
 import oss2
 from sail_utils import LOGGER
 
@@ -78,3 +80,24 @@ class OSSUtility:
         :return:
         """
         return self._bucket.object_exists(key)
+
+    def download(self, key: str, file_name: str):
+        """
+        download a file from an existing oss2 bucket
+        """
+        file_name = Path(file_name)
+        key = Path(key).as_posix()
+        with LockFile(file_name.as_posix() + '.lock'):
+            if not file_name.exists():
+                LOGGER.info(f'downloading <{key}> '
+                            f'from <{self._bucket.endpoint}/{self._bucket.bucket_name}> '
+                            f'to <{file_name}>')
+                try:
+                    oss2.resumable_download(self._bucket, key, file_name.as_posix(),
+                                            multiget_threshold=200 * 1024,
+                                            part_size=100 * 1024)
+                except oss2.exceptions.NotFound:
+                    LOGGER.warning(f'<{key}> not found on the oss')
+                    raise
+            else:
+                LOGGER.info(f'<{file_name}> already exists. Omit downloading')
